# encoding: utf-8
#
# Copyright (C) 2020 willipink.eu
# Author Moritz Münch moritzmuench@mailbox.org
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.



from datetime import datetime

from django.http import HttpResponse
from django.template import loader
from django.template.defaultfilters import register

from .models import Country



def index(request):
    countrys = Country.objects.order_by('name')
    template = loader.get_template('coinc/index.html')
    year_now = datetime.now().year
    context = {'countrys': countrys}

    return HttpResponse(template.render(context, request))


def country(request, country):
    return HttpResponse(f"Land: {country}")


@register.inclusion_tag('coinc/navigation.html')
def navigation(countrys):
    return {'countrys': countrys}


@register.filter(name='coins')
def coins(country, year):
    return country['years'][year]


@register.inclusion_tag('coinc/country.html')
def show_country(country):
    year_now = datetime.now().year
    c = {
        'name_iso': country.name_iso,
        'name': country.name,
        'comment': country.comment,
        'euro_member_since': country.euro_member_since,
        'years': {}
    }

    for year in range(country.euro_member_since, year_now + 1):
        y = str(year)[2:4]
        c['years'][y] = {
            '1': 'x',
            '2': '',
            '5': '',
            '10': '',
            '20': 'x',
            '50': '',
            '100': '',
            '200': 'x',
            '201': '',
            '202': '',
            '203': ''
        }

    return {'country': c}


def statistic(request):
    return HttpResponse('Statistik')
